from __future__ import annotations

from dataclasses import asdict
from typing import Any

from xarray import DataArray


def rename_data_arrays(obj: Any, /) -> None:
    """Rename the arrays on a field."""
    for key, value in asdict(obj).items():
        if isinstance(value, DataArray) and (value.name != key):
            setattr(obj, key, value.rename(key))


__all__ = [
    "rename_data_arrays",
]



from __future__ import annotations

from dataclasses import is_dataclass
from typing import Any


def is_dataclass_instance(obj: Any, /) -> bool:
    """Check if an object is an instance of a dataclass."""

    return (not isinstance(obj, type)) and is_dataclass(obj)


__all__ = [
    "is_dataclass_instance",
]



from __future__ import annotations

from dataclasses import dataclass
from typing import Any

from pytest import mark, param

from utilities.dataclasses import is_dataclass_instance


class TestIsDataClassInstance:
    def test_main(self) -> None:
        @dataclass
        class Example:
            x: None = None

        assert not is_dataclass_instance(Example)
        assert is_dataclass_instance(Example())

    @mark.parametrize("obj", [param(None), param(True), param(False)])
    def test_others(self, *, obj: Any) -> None:
        assert not is_dataclass_instance(obj)
